@@ -1,10 +1,32 @@
 {
 package MyTest::Role1;
-our $USES_MITE = "Mite::Role";
-our $MITE_SHIM = "MyTest::Mite";
 use strict;
 use warnings;
 
+our $USES_MITE = "Mite::Role";
+our $MITE_SHIM = "MyTest::Mite";
+our $MITE_VERSION = "0.008003";
+# Gather metadata for constructor and destructor
+sub __META__ {
+    no strict 'refs';
+    no warnings 'once';
+    my $class      = shift; $class = ref($class) || $class;
+    my $linear_isa = mro::get_linear_isa( $class );
+    return {
+        BUILD => [
+            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+            map { "$_\::BUILD" } reverse @$linear_isa
+        ],
+        DEMOLISH => [
+            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+            map { "$_\::DEMOLISH" } @$linear_isa
+        ],
+        HAS_BUILDARGS => $class->can('BUILDARGS'),
+        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
+    };
+}
+
+# See UNIVERSAL
 sub DOES {
     my ( $self, $role ) = @_;
     our %DOES;
@@ -13,6 +35,7 @@ sub DOES {
     return $self->SUPER::DOES( $role );
 }
 
+# Alias for Moose/Moo-compatibility
 sub does {
     shift->DOES( @_ );
 }
