@@ -1,11 +1,13 @@
 {
 package MyTest::TestClass::String;
-our $USES_MITE = "Mite::Class";
-our $MITE_SHIM = "MyTest::Mite";
 use strict;
 use warnings;
 
+our $USES_MITE = "Mite::Class";
+our $MITE_SHIM = "MyTest::Mite";
+our $MITE_VERSION = "0.008003";
 
+# Standard Moose/Moo-style constructor
 sub new {
     my $class = ref($_[0]) ? ref(shift) : shift;
     my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
@@ -13,25 +15,28 @@ sub new {
     my $args  = $meta->{HAS_BUILDARGS} ? $class->BUILDARGS( @_ ) : { ( @_ == 1 ) ? %{$_[0]} : @_ };
     my $no_build = delete $args->{__no_BUILD__};
 
-        # Attribute: attr
-    do { my $value = exists( $args->{"attr"} ) ? $args->{"attr"} : do { my $method = $MyTest::TestClass::String::__attr_DEFAULT__; $self->$method }; do { package MyTest::Mite; defined($value) and do { ref(\$value) eq 'SCALAR' or ref(\(my $val = $value)) eq 'SCALAR' } } or MyTest::Mite::croak "Type check failed in constructor: %s should be %s", "attr", "Str"; $self->{"attr"} = $value; }; 
+    # Attribute attr (type: Str)
+    # has declaration, file lib/MyTest/TestClass/String.pm, line 41
+    do { my $value = exists( $args->{"attr"} ) ? $args->{"attr"} : $MyTest::TestClass::String::__attr_DEFAULT__->( $self ); do { package MyTest::Mite; defined($value) and do { ref(\$value) eq 'SCALAR' or ref(\(my $val = $value)) eq 'SCALAR' } } or MyTest::Mite::croak "Type check failed in constructor: %s should be %s", "attr", "Str"; $self->{"attr"} = $value; }; 
 
 
-    # Enforce strict constructor
-    my @unknown = grep not( /\Aattr\z/ ), keys %{$args}; @unknown and MyTest::Mite::croak( "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
-
     # Call BUILD methods
     $self->BUILDALL( $args ) if ( ! $no_build and @{ $meta->{BUILD} || [] } );
 
+    # Unrecognized parameters
+    my @unknown = grep not( /\Aattr\z/ ), keys %{$args}; @unknown and MyTest::Mite::croak( "Unexpected keys in constructor: " . join( q[, ], sort @unknown ) );
+
     return $self;
 }
 
+# Used by constructor to call BUILD methods
 sub BUILDALL {
     my $class = ref( $_[0] );
     my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
     $_->( @_ ) for @{ $meta->{BUILD} || [] };
 }
 
+# Destructor should call DEMOLISH methods
 sub DESTROY {
     my $self  = shift;
     my $class = ref( $self ) || $self;
@@ -51,8 +56,10 @@ sub DESTROY {
     return;
 }
 
+# Gather metadata for constructor and destructor
 sub __META__ {
     no strict 'refs';
+    no warnings 'once';
     my $class      = shift; $class = ref($class) || $class;
     my $linear_isa = mro::get_linear_isa( $class );
     return {
@@ -69,6 +76,7 @@ sub __META__ {
     };
 }
 
+# See UNIVERSAL
 sub DOES {
     my ( $self, $role ) = @_;
     our %DOES;
@@ -77,6 +85,7 @@ sub DOES {
     return $self->SUPER::DOES( $role );
 }
 
+# Alias for Moose/Moo-compatibility
 sub does {
     shift->DOES( @_ );
 }
@@ -84,6 +93,7 @@ sub does {
 my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for attr
+# has declaration, file lib/MyTest/TestClass/String.pm, line 41
 if ( $__XS ) {
     Class::XSAccessor->import(
         chained => 1,
@@ -91,9 +101,9 @@ if ( $__XS ) {
     );
 }
 else {
-    *attr = sub { @_ > 1 ? MyTest::Mite::croak( "attr is a read-only attribute of @{[ref $_[0]]}" ) : $_[0]{"attr"} };
+    *attr = sub { @_ == 1 or MyTest::Mite::croak( 'Reader "attr" usage: $self->attr()' ); $_[0]{"attr"} };
 }
-sub _set_attr { do { package MyTest::Mite; defined($_[1]) and do { ref(\$_[1]) eq 'SCALAR' or ref(\(my $val = $_[1])) eq 'SCALAR' } } or MyTest::Mite::croak( "Type check failed in %s: value should be %s", "writer", "Str" ); $_[0]{"attr"} = $_[1]; $_[0]; }
+sub _set_attr { @_ == 2 or MyTest::Mite::croak( 'Writer "_set_attr" usage: $self->_set_attr( $newvalue )' ); do { package MyTest::Mite; defined($_[1]) and do { ref(\$_[1]) eq 'SCALAR' or ref(\(my $val = $_[1])) eq 'SCALAR' } } or MyTest::Mite::croak( "Type check failed in %s: value should be %s", "writer", "Str" ); $_[0]{"attr"} = $_[1]; $_[0]; }
 
 
 1;
